@@ -1,4 +1,4 @@
-/* $Id: swap.c,v 1.3 2004/06/09 18:52:21 bdejean Exp $ */
+/* $Id: swap.c,v 1.5 2005/12/12 09:38:10 jamesh Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -21,6 +21,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <sys/vminfo.h>
 
 #include <glibtop.h>
@@ -57,6 +58,8 @@ glibtop_get_swap_s (glibtop *server, glibtop_swap *buf)
 	int comment = 0;
 	int pos = 0;
 
+	glibtop_init_s (&server, (1L << GLIBTOP_SYSDEPS_SWAP), 0);
+
 	memset (buf, 0, sizeof (glibtop_swap));
 
 	pagesize = sysconf(_SC_PAGESIZE);
